==> haskell-store-0.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.3
id: store-0.3-KcbhWbZXANaF4aaxhxROCT
key: store-0.3-KcbhWbZXANaF4aaxhxROCT
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
abi: 813ff9c366f8a51461b371ae1dd87d0e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/store-0.3
hs-libraries: HSstore-0.3-KcbhWbZXANaF4aaxhxROCT
depends:
    array-0.5.1.1 async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    containers-0.5.7.1 cryptohash-0.11.9-6KWjXG2Y77tCLfbEj0PLeD
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    free-4.12.4-LcxMyZIxIoo6h2gqXah9QK ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    hspec-2.3.2-AN9xcjaacLKEAAGjKcxxHS
    hspec-smallcheck-0.4.1-KiG5f4ZmbZM8bVyPTNQdIt integer-gmp-1.0.0.1
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1-BmUD1sLqDo7dtBcdyOCS9
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    safe-0.3.10-1VyrsjWhmjvGnGud5lgW7f
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
    store-core-0.3-DRh8eWR12WHG6VUHAXGWU4
    streaming-commons-0.1.16-CLBwBEuHY5s2yAYGJkabL9
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.6-3YgW6AFnN6SEjgDav6Czfy
    th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
    th-orphans-0.13.3-7wLyxulUCYmKNm2wp8f3pf
    th-reify-many-0.1.6-5d4Cv6drUd389ikqksOzkP
    th-utilities-0.2.0.1-E56LHPUMEiQ52YJCb3HGGw time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-0.3-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.3
id: store-0.3-BTHOjlEXvf2DLRfdmc1tF4
key: store-0.3-BTHOjlEXvf2DLRfdmc1tF4
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
abi: 603c613e9c95bd8772f3e6de2227671f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/store-0.3
hs-libraries: HSstore-0.3-BTHOjlEXvf2DLRfdmc1tF4
depends:
    array-0.5.1.1 async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    containers-0.5.7.1 cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    free-4.12.4-Aed7uNZqrKqF7XkiVApgap ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hspec-2.3.2-AN9xcjaacLKEAAGjKcxxHS
    hspec-smallcheck-0.4.1-KiG5f4ZmbZM8bVyPTNQdIt integer-gmp-1.0.0.1
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1.1-7rlAYW3rlGWBRxOTFStZDt
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    safe-0.3.10-1VyrsjWhmjvGnGud5lgW7f
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
    store-core-0.3-DRh8eWR12WHG6VUHAXGWU4
    streaming-commons-0.1.16-CLBwBEuHY5s2yAYGJkabL9
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.6-3YgW6AFnN6SEjgDav6Czfy
    th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
    th-orphans-0.13.3-CGCiG5NgPcjAFcLAC9siQe
    th-reify-many-0.1.6-1IHZfd9bw2pK00gAexetFN
    th-utilities-0.2.0.1-G0A3ncEstEg7o9JIA2nudH time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
